@@ -4,8 +4,8 @@
 
 ;; Author: SAKURAI Masashi <m.sakurai at kiwanami.net>
 ;; Maintainer: Al Haji-Ali <abdo.haji.ali at gmail.com>
-;; Package-Version: 20251024.1918
-;; Package-Revision: bcb01c7afa1b
+;; Package-Version: 20251030.845
+;; Package-Revision: 57be107b2062
 ;; Keywords: calendar, org
 ;; Package-Requires: ((emacs "28.1") (calfw "2.0"))
 ;; URL: https://github.com/haji-ali/emacs-calfw
@@ -43,6 +43,7 @@
 
 (require 'calfw)
 (require 'calendar)
+(require 'diary-lib)  ;; for diary-make-date
 
 (defvar calfw-cal-diary-regex
   (let ((time   "[[:digit:]]\\{2\\}:[[:digit:]]\\{2\\}")
@@ -50,8 +51,7 @@
     (concat "\\(" time "\\)?"
             "\\(?:" blanks "-" blanks "\\(" time "\\)\\)?"
             blanks "\\(.*\\)"))
-  "Regex extracting start/end time and title from a diary string."
-  )
+  "Regex extracting start/end time and title from a diary string.")
 
 (defun calfw-cal--entry-to-event (date string)
   "Create a `calfw-event` from a diary entry STRING on DATE.
@@ -61,7 +61,7 @@ Return the `calfw-event`."
                        "[\t ]+" " " (string-trim string))
                       "\n"))
          (first      (car lines))
-         (desc       (mapconcat 'identity (cdr lines) "\n"))
+         (desc       (mapconcat #'identity (cdr lines) "\n"))
          (title      (progn
                        (string-match calfw-cal-diary-regex first)
                        (match-string 3 first)))
@@ -70,13 +70,13 @@ Return the `calfw-event`."
          (properties (list 'mouse-face 'highlight
                            'help-echo string
                            'cfw-marker (copy-marker (point-at-bol)))))
-    (make-calfw-event :title       (apply 'propertize title properties)
+    (make-calfw-event :title       (apply #'propertize title properties)
                       :start-date  date
                       :start-time  (when start
                                      (calfw-parse-str-time start))
                       :end-time    (when end
                                      (calfw-parse-str-time end))
-                      :description (apply 'propertize desc properties))))
+                      :description (apply #'propertize desc properties))))
 
 (defun calfw-cal-onclick ()
   "Jump to the clicked diary item."
@@ -138,26 +138,31 @@ Return the `calfw-event`."
      ("i" . calfw-cal-from-calendar)))
   "Key map for the calendar buffer.")
 
-(defun calfw-cal-create-source (&optional color)
-  "Create diary calendar source.
+(defun calfw-cal-create-source (name color)
+  "Create a calfw source with NAME and COLOR from `calendar'."
+  (make-calfw-source :name name :color color
+                     :data 'calfw-cal--schedule-period-to-calendar))
 
-COLOR is the color to use for diary entries.
-Returns the calendar source."
-  (make-calfw-source
-   :name "calendar diary"
-   :color (or color "SaddleBrown")
-   :data 'calfw-cal--schedule-period-to-calendar))
+(cl-defun calfw-cal-open-diary-calendar
+    (&optional (name "calendar diary")
+               (color "SaddleBrown")
+               &rest args
+               &key
+               (view 'month)
+               (custom-map calfw-cal-schedule-map)
+               &allow-other-keys)
+  "Open the diary schedule calendar in a new buffer.
 
-(defun calfw-cal-open-diary-calendar ()
-  "Open the diary schedule calendar in the new buffer."
+Optional arguments NAME, COLOR, and ARGS are passed to
+`calfw-open-calendar-buffer'.  VIEW specifies the
+initial view.  CUSTOM-MAP specifies the keymap."
   (interactive)
-  (save-excursion
-    (let* ((source1 (calfw-cal-create-source))
-           (cp (calfw-create-calendar-component-buffer
-                :view 'month
-                :custom-map calfw-cal-schedule-map
-                :contents-sources (list source1))))
-      (switch-to-buffer (calfw-cp-get-buffer cp)))))
+  (apply #'calfw-open-calendar-buffer
+         :view view
+         :custom-map custom-map
+         :contents-sources
+         (list (calfw-cal-create-source name color))
+         args))
 
 (defun calfw-cal-from-calendar ()
   "Insert a new item.  This command should be executed on the calfw calendar."
